# credentials.py - script functions developed for integration with ScienceCloud via PipelinePilot server
# Use of this code is subject to the terms of the StarDrop License Agreement and use, copying or redistribution of this file for use by other persons or organisations is prohibited
# Copyright(C) Optibrium Ltd 2017
# stardrop-support@optibrium.com
#
"""
Module handles user access credentials to the ScienceCloud server.
"""
import urllib.request as request

class CredentialsManager():
    """Class to store credentials."""
    def __init__(self,user,password,config):
        """Create a CredentialsManager. Throws ValueError if user and password not specified.
        @param: user: The ScienceCloud user name.
        @param: password: The ScienceCloud password.
        @param: config: The ScienceCloud configuration options.
        """
        if user == "" or password == "":
            raise ValueError("User and pasword must be completed")
        self._user = user
        self._password = password
        password_manager = request.HTTPPasswordMgr()
        password_manager.add_password("AEP Services",config.base_url,user,password)
        authorization_handler = request.HTTPBasicAuthHandler(password_manager)
        opener = request.build_opener(authorization_handler)
        request.install_opener(opener)
        self.configured = True
        
    def getUser(self):
        """Get the user name.
        @return: User name
        """
        return self._user
        
    def getPassword(self):
        """Get the password.
        @return: Password
        """
        return self._password

    def clear(self):
        """Clear the current credentials after a login failure."""
        self.configured = False